@@ -449,8 +449,8 @@ configure_recipe(){
     # beginning of the epoch, so work around this pair of silliness
     # by setting old mtimes to 1998
     reftime=$(mktemp)
-    touch -d 1975-01-01 "${reftime}"
-    find . \! -newer "${reftime}" -exec touch -d 1998-01-01 {} \;
+    touch -d "1975-01-01 UTC" "${reftime}"
+    find . \! -newer "${reftime}" -exec touch -d "1998-01-01 UTC" {} \;
     rm "${reftime}"
 
     hc=`packages_hc`
